/******************************************************************************
*******************             Port functions/macros       *******************
*******************************************************************************

Macros for simplifying access to I/O pin setup and usage.

MCU pin configuration:
---------------------------------------------
| Peripheral I/O signal  |  Alt1   |   Alt2 |
---------------------------------------------
| Timer1 channel0        |  P0.2   |   P1.2 |
| Timer1 channel1        |  P0.3   |   P1.1 |
| Timer1 channel2        |  P0.4   |   P1.0 |
| Timer3 channel0        |  P1.3   |   P1.6 |
| Timer3 channel1        |  P1.4   |   P1.7 |
| Timer4 channel0        |  P1.0   |   P2.0 |
| Timer4 channel1        |  P1.1   |   P2.3 |
| USART0 TXD/MOSI        |  P0.3   |   P1.5 |
| USART0 RXD/MISO        |  P0.2   |   P1.4 |
| USART0 RTS/SCK         |  P0.5   |   P1.3 |
| USART0 CTS/SS_N        |  P0.4   |   P1.2 |
| USART1 TXD/MOSI        |  P0.4   |   P1.6 |
| USART1 RXD/MISO        |  P0.5   |   P1.7 |
| USART1 RTS/SCK         |  P0.3   |   P1.5 |
| USART1 CTS/SS_N        |  P0.2   |   P1.4 |
---------------------------------------------

******************************************************************************/


// Macros for configuring IO peripheral location:
// Example usage:
//   IO_PER_LOC_TIMER1_AT_PORT0_PIN234();
//   IO_PER_LOC_TIMER4_AT_PORT2_PIN03();
//   IO_PER_LOC_USART1_AT_PORT0_PIN2345();

#define IO_PER_LOC_TIMER1_AT_PORT0_PIN234()  do { PERCFG = (PERCFG&~0x40)|0x00; } while (0)
#define IO_PER_LOC_TIMER1_AT_PORT1_PIN012()  do { PERCFG = (PERCFG&~0x40)|0x40; } while (0)

#define IO_PER_LOC_TIMER3_AT_PORT1_PIN34()   do { PERCFG = (PERCFG&~0x20)|0x00; } while (0)
#define IO_PER_LOC_TIMER3_AT_PORT1_PIN67()   do { PERCFG = (PERCFG&~0x20)|0x20; } while (0)

#define IO_PER_LOC_TIMER4_AT_PORT1_PIN01()   do { PERCFG = (PERCFG&~0x10)|0x00; } while (0)
#define IO_PER_LOC_TIMER4_AT_PORT2_PIN03()   do { PERCFG = (PERCFG&~0x10)|0x10; } while (0)

#define IO_PER_LOC_USART1_AT_PORT0_PIN2345() do { PERCFG = (PERCFG&~0x02)|0x00; } while (0)
#define IO_PER_LOC_USART1_AT_PORT1_PIN4567() do { PERCFG = (PERCFG&~0x02)|0x02; } while (0)

#define IO_PER_LOC_USART0_AT_PORT0_PIN2345() do { PERCFG = (PERCFG&~0x01)|0x00; } while (0)
#define IO_PER_LOC_USART0_AT_PORT1_PIN2345() do { PERCFG = (PERCFG&~0x01)|0x01; } while (0)
